Yuvipanda has submitted this change and it was merged.

Change subject: Use .alpha and not .master
......................................................................


Use .alpha and not .master

Change-Id: I19bfaacc2bb02ba5eb20d177465556bc20b289e1
---
M src/build.py
1 file changed, 2 insertions(+), 2 deletions(-)

Approvals:
  Yuvipanda: Verified; Looks good to me, approved



diff --git a/src/build.py b/src/build.py
index f461237..bdf7a0c 100755
--- a/src/build.py
+++ b/src/build.py
@@ -38,9 +38,9 @@
 
     meta['commit_hash'] = commit_hash
 
     # Change the package name to .master
     prepare_release = 
sh.Command(os.path.expanduser('~/wikipedia/scripts/prepare-release.py'))
-    prepare_release('--custompackage', 'master')
+    prepare_release('--alpha')
 
     print 'Starting build for %s, with %s new commits' % (commit_hash, 
@@ -38,9 +38,9 @@
     meta['commit_hash'] = commit_hash
 
-    # Change the package name to .master
+    # Change the package name to .alpha
     prepare_release = 
sh.Command(os.path.expanduser('~/wikipedia/scripts/prepare-release.py'))
commit_count)
     # Run in side the app folder, since we can't run

-- 
To view, visit https://gerrit.wikimedia.org/r/155801
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: I19bfaacc2bb02ba5eb20d177465556bc20b289e1
Gerrit-PatchSet: 1
Gerrit-Project: labs/tools/wikipedia-android-builds
Gerrit-Branch: master
Gerrit-Owner: Yuvipanda <[email protected]>
Gerrit-Reviewer: Yuvipanda <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to